exampleplugincrd

package
v0.0.0-...-0bdd209 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 12, 2018 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Overview

Package exampleplugincrd implements the example CRD plugin

Index

Constants

const QueueRetryCount = 5

QueueRetryCount is the max number of times to retry processing a failed item from the workqueue.

Variables

This section is empty.

Functions

This section is empty.

Types

type Deps

type Deps struct {
	local.PluginInfraDeps
	// Kubeconfig with k8s cluster address and access credentials to use.
	KubeConfig config.PluginConfig
}

Deps defines dependencies of netmesh plugin.

type Plugin

type Plugin struct {
	Deps
	// contains filtered or unexported fields
}

Plugin watches K8s resources and causes all changes to be reflected in the ETCD data store.

func (*Plugin) AfterInit

func (plugin *Plugin) AfterInit() error

AfterInit This will create all of the CRDs for NetworkServiceMesh.

func (*Plugin) Close

func (plugin *Plugin) Close() error

Close stops all reflectors.

func (*Plugin) Init

func (plugin *Plugin) Init() error

Init builds K8s client-set based on the supplied kubeconfig and initializes all reflectors.

Jump to